@@ -1,5 +1,6 @@
 from typing import cast
 
+from pyfileconf.sectionpath.sectionpath import SectionPath
 from pyfileconf.selector.logic.exc.typo import (
     handle_pipeline_manager_not_loaded_or_typo,
     handle_known_typo_at_end_of_section_path_str,
@@ -23,6 +24,7 @@ class ItemView:
         self._is_item_view = True
 
     def __getattr__(self, item):
+        from pyfileconf.main import PipelineManager
         full_section_path_str = self.section_path_str + '.' + item
         if full_section_path_str in self.selector:
             # This is an item, return an item view for it
@@ -50,13 +52,19 @@ class ItemView:
             return handle_known_typo_after_pipeline_manager_name(full_section_path_str)
 
         try:
-            return getattr(actual_item, item)
+            result = getattr(actual_item, item)
         except (KeyError, AttributeError) as e:
             ### TEMP - having issues with _is_selector
             raise e
             ### END TEMP
             return handle_known_typo_at_end_of_section_path_str(full_section_path_str)
 
+        # Got attribute of actual item
+        # If this happened while running another item, add to dependencies
+        self._add_to_config_dependencies_if_necessary()
+
+        return result
+
     def __setattr__(self, key: str, value):
         # Set these items on ItemView itself
         item_view_set_attrs = [
@@ -81,6 +89,8 @@ class ItemView:
     def __call__(self, *args, **kwargs):
         # When calling, assume user always wants the real item
         actual_item = self.selector._get_real_item(self.section_path_str)
+        # If this happened while running another item, add to dependencies
+        self._add_to_config_dependencies_if_necessary()
         return actual_item(*args, **kwargs)
 
     def __deepcopy__(self, memodict={}):
@@ -114,6 +124,18 @@ class ItemView:
     def item(self):
         return self.selector._get_real_item(self.section_path_str)
 
+    def _add_to_config_dependencies(self):
+        from pyfileconf.main import PipelineManager
+        running_sp = SectionPath(PipelineManager._currently_running_section_path_str)
+        PipelineManager._config_attribute_dependencies[self.section_path_str].add(running_sp)
+        PipelineManager.config_dependencies[self.section_path_str].add(running_sp)
+
+    def _add_to_config_dependencies_if_necessary(self):
+        from pyfileconf.main import PipelineManager
+        # If this happened while running another item, add to dependencies
+        if PipelineManager._currently_running_section_path_str is not None:
+            self._add_to_config_dependencies()
+
 
 def _is_item_view(obj) -> bool:
     is_item_view = getattr(obj, '_is_item_view', False)
