@@ -108,6 +108,23 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         assert result[1]() == (None, expected_b_result)
         assert PipelineManager.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
 
+    def test_config_update_function_dependencies(self):
+        self.write_a_function_to_pipeline_dict_file()
+        self.write_a_function_to_pipeline_dict_file(file_path=self.second_pipeline_dict_path)
+        pipeline_manager = self.create_pm()
+        pipeline_manager.load()
+        pipeline_manager2 = self.create_pm(
+            folder=self.second_pm_folder,
+            name=self.second_test_name,
+        )
+        pipeline_manager2.load()
+        sel = Selector()
+        pipeline_manager.update(
+            section_path_str='stuff.a_function',
+            b=sel.test_pipeline_manager2.stuff.a_function
+        )
+        assert PipelineManager.config_dependencies == self.expect_pm_1_a_function_depends_on_pm_2_a_function
+
     def test_config_update_class(self):
         self.write_example_class_to_pipeline_dict_file()
         pipeline_manager = self.create_pm()
@@ -209,6 +226,24 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         assert ec.a().a == expected_a_result
         assert PipelineManager.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
 
+    def test_config_update_class_dependencies(self):
+        self.write_example_class_to_pipeline_dict_file()
+        self.write_example_class_to_pipeline_dict_file(file_path=self.second_pipeline_dict_path)
+        pipeline_manager = self.create_pm()
+        pipeline_manager.load()
+        pipeline_manager2 = self.create_pm(
+            folder=self.second_pm_folder,
+            name=self.second_test_name,
+        )
+        pipeline_manager2.load()
+        sel = Selector()
+        pipeline_manager.update(
+            section_path_str='stuff.ExampleClass',
+            a=sel.test_pipeline_manager2.stuff.ExampleClass
+        )
+        assert PipelineManager.config_dependencies == self.expect_pm_1_class_depends_on_pm_2_class
+
+
     def test_create_update_from_specific_class_dict(self):
         self.write_example_class_dict_to_file()
         pipeline_manager = self.create_pm(
@@ -328,6 +363,26 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         assert ec.a.a == expected_a_result
         assert PipelineManager.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
 
+    def test_create_update_specific_class_dependencies(self):
+        self.write_example_class_dict_to_file()
+        self.write_example_class_dict_to_file(pm_index=1)
+        pipeline_manager = self.create_pm(
+            specific_class_config_dicts=CLASS_CONFIG_DICT_LIST
+        )
+        pipeline_manager.load()
+        pipeline_manager2 = self.create_pm(
+            folder=self.second_pm_folder,
+            name=self.second_test_name,
+            specific_class_config_dicts=CLASS_CONFIG_DICT_LIST,
+        )
+        pipeline_manager2.load()
+        sel = Selector()
+        pipeline_manager.update(
+            section_path_str='example_class.stuff.data',
+            a=sel.test_pipeline_manager2.example_class.stuff.data,
+        )
+        assert PipelineManager.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
+
     def test_create_update_from_specific_class_dict_multiple_dependent_attribute_pms(self):
         self.write_example_class_dict_to_file()
         self.write_example_class_dict_to_file(pm_index=1)
@@ -365,7 +420,8 @@ class TestPipelineManagerConfig(PipelineManagerTestBase):
         ec = sel.test_pipeline_manager.example_class.stuff.data.item
         assert ec == expect_1
         assert ec.a == expected_a_result
-        assert PipelineManager.config_dependencies == self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
+        assert PipelineManager.config_dependencies == PipelineManager._config_attribute_dependencies == \
+               self.expect_pm_1_specific_class_depends_on_pm_2_specific_class
 
     def test_create_update_from_multiple_specific_class_dicts_same(self):
         self.write_example_class_dict_to_file()  # example_class
